import './index.css';
import dayjs from 'dayjs';
import { Swiper, View, SwiperItem } from '@tarojs/components';
import { useState } from 'react';
import cs from 'classnames';
import { jsx, jsxs } from 'react/jsx-runtime';

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"];

  if (_i == null) return;
  var _arr = [];
  var _n = true;
  var _d = false;

  var _s, _e;

  try {
    for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) {
    arr2[i] = arr[i];
  }

  return arr2;
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
}

/**
 * 获取日期别称
 * 根据传入日期，返回前天 昨天 今天 明天 后天等
 * @param curren 当前日期
 * @returns前天 昨天 今天 明天 后天等日期别称
 */

var getDateNickname = function getDateNickname(current) {
  var dataNickname = {
    // "-2": "前天",
    "-1": "昨天",
    "0": "今天",
    "1": "明天" // "2": "后天"

  };
  var today = dayjs().format("YYYY-MM-DD");
  var diffDay = dayjs(current).diff(today, "day", true);
  return dataNickname[diffDay];
};
/**
 * 根据传入日期，返回周几
 * @param curren 当前日期
 * @returns 周几
 */


var getWeekName = function getWeekName(current) {
  var hideNickname = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  var dataNickname = getDateNickname(current);

  if (dataNickname && !hideNickname) {
    return dataNickname;
  } else {
    var dayNum = dayjs(current).get("day");
    return ["周日", "周一", "周二", "周三", "周四", "周五", "周六"][dayNum];
  }
};
var weekArr = [1, 2, 3, 4, 5, 6, 7];
/**
 * 传入当前日期 获取上周 本周 下周的日期二维数组
 * @param current 当前日期
 * @returns 上周 本周 下周的日期二维数组
 */

var getWeekDay = function getWeekDay() {
  var current = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : new Date();
  // 获取当前一周的 7天日期
  var weekFirstDay = dayjs(current).startOf("week").add(1, "day"); // 当前周的第一天

  var currentWeekDay = weekArr.map(function (_, index) {
    return dayjs(weekFirstDay).add(index, "day").format("YYYY-MM-DD");
  }); // 获取当前一周的 7天日期（将今天放在在第一位 而不是将周一放在第一位）
  // const currentWeekDay = weekArr.map((item, index) =>
  //   dayjs(current)
  //     .add(index, "day")
  //     .format("YYYY-MM-DD")
  // );
  // 获取上周的 7天日期

  var preWeekDay = weekArr.map(function (item) {
    return dayjs(currentWeekDay[0]).subtract(item, "day").format("YYYY-MM-DD");
  }).reverse(); // 获取下周的 7天日期

  var nextWeekDay = weekArr.map(function (item) {
    return dayjs(currentWeekDay[currentWeekDay.length - 1]).add(item, "day").format("YYYY-MM-DD");
  });
  return [preWeekDay, currentWeekDay, nextWeekDay];
};
var getSwiperIndex = function getSwiperIndex(current) {
  var type = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "next";
  var nextDict = {
    0: 1,
    1: 2,
    2: 0
  };
  var preDict = {
    0: 2,
    1: 0,
    2: 1
  };
  return type === "pre" ? preDict[current] : nextDict[current];
};

var index = (function (props) {
  // Swiper初始化 上周 本周 下周的数据
  var _useState = useState(getWeekDay()),
      _useState2 = _slicedToArray(_useState, 2),
      weekDays = _useState2[0];
      _useState2[1]; // Swiper当前展示的面板索引 默认是1 即显示本周的日期组


  var _useState3 = useState(1),
      _useState4 = _slicedToArray(_useState3, 2),
      activeSwiper = _useState4[0],
      setActiveSwiper = _useState4[1]; // 当前激活的选中日期


  var _useState5 = useState(props.value),
      _useState6 = _slicedToArray(_useState5, 2),
      activeDay = _useState6[0],
      setActiveDay = _useState6[1];
  /**
   * 日期点击
   */


  var dayClick = function dayClick(item) {
    setActiveDay(item);
    props.onChange(item);
  };
  /**
   * Swiper 滚动事件
   * 通过滚动 提前计算并复制好 即将到来的一周日期组
   */


  var onSwiperChange = function onSwiperChange(e) {
    var oIndex = e.detail.current;
    var ind = oIndex - activeSwiper;
    var comeGroup = weekDays[oIndex];

    if (ind === 1 || ind === -2) {
      // 向左滑动:给即将到来的下一轮设置新值
      var lastDay = comeGroup[comeGroup.length - 1];
      var swiperIndex = getSwiperIndex(oIndex);
      weekDays[swiperIndex] = getWeekDay(lastDay)[1];
    } else if (ind === -1 || ind === 2) {
      // 向右滑动:给即将到来的上一轮设置新值
      var fistDay = comeGroup[0];
      console.log(fistDay, getWeekDay(fistDay)[0]);

      var _swiperIndex = getSwiperIndex(oIndex, "pre");

      weekDays[_swiperIndex] = getWeekDay(fistDay)[0];
    }

    setActiveSwiper(oIndex);
  };

  console.log(Swiper);
  return /*#__PURE__*/jsx(View, {
    className: "week-swiper",
    children: /*#__PURE__*/jsx(Swiper, {
      circular: true,
      current: activeSwiper,
      onChange: onSwiperChange,
      className: "week-swiper-wrapp",
      children: weekDays.map(function (weekDay, index) {
        return /*#__PURE__*/jsx(SwiperItem, {
          children: /*#__PURE__*/jsx(View, {
            className: "items",
            children: weekDay.map(function (item, itemIndex) {
              return /*#__PURE__*/jsxs(View, {
                className: cs("item", {
                  tody: dayjs().isSame(item, "day"),
                  active: dayjs(activeDay).isSame(dayjs(item), "date")
                }),
                onClick: function onClick() {
                  dayClick(item);
                },
                children: [/*#__PURE__*/jsx(View, {
                  className: "week",
                  children: getWeekName(item, props.hideNickname)
                }), /*#__PURE__*/jsx(View, {
                  className: "day",
                  children: dayjs(item).format("MM-DD")
                })]
              }, index + '-' + itemIndex);
            })
          }, index)
        }, index);
      })
    })
  });
});

export { index as default };
